@@ -8,7 +8,7 @@ class scrapingConfig(cmnConfig):
     scrapinger共通設定クラス(scrapingConfig)
     """ 
     
-    class settingValueStruct:
+    class settingValueStruct(cmnConfig.settingValueStruct):
         
         """
         設定値構造体
